@@ -1,67 +1,17 @@
 use ansi_term::Colour::Red;
-use clap::{builder::styling::AnsiColor, builder::Styles, crate_version, Parser, Subcommand};
+use clap::{crate_version, Parser};
+use itertools::Itertools;
 
+use debcargo::cli::{Cli, Opt};
 use debcargo::crates::CrateInfo;
 use debcargo::debian::DebInfo;
 use debcargo::errors::Result;
 use debcargo::package::*;
 use debcargo::{
-    build_order::{build_order, BuildOrderArgs},
-    crates::invalidate_crates_io_cache,
+    build_order::build_order, crates::invalidate_crates_io_cache,
+    deb_dependencies::deb_dependencies,
 };
 
-const CLI_STYLE: Styles = Styles::styled()
-    .header(AnsiColor::Yellow.on_default())
-    .usage(AnsiColor::Green.on_default())
-    .literal(AnsiColor::Green.on_default())
-    .placeholder(AnsiColor::Green.on_default());
-
-#[derive(Debug, Clone, Parser)]
-#[command(name = "debcargo", about = "Package Rust crates for Debian.")]
-#[command(version)]
-#[command(styles = CLI_STYLE)]
-struct Cli {
-    #[command(subcommand)]
-    command: Opt,
-}
-
-#[derive(Debug, Clone, Subcommand)]
-enum Opt {
-    /// Update the user's default crates.io index, outside of a workspace.
-    Update,
-    /// Print the Debian package name for a crate.
-    DebSrcName {
-        /// Name of the crate to package.
-        crate_name: String,
-        /// Version of the crate to package; may contain dependency operators.
-        /// If empty string, resolves to the latest version. If given here,
-        /// i.e. not omitted then print the package name as if the config
-        /// option semver_suffix was set to true.
-        version: Option<String>,
-    },
-    /// Extract only a crate, without any other transformations.
-    Extract {
-        #[command(flatten)]
-        init: PackageInitArgs,
-        #[command(flatten)]
-        extract: PackageExtractArgs,
-    },
-    /// Package a Rust crate for Debian.
-    Package {
-        #[command(flatten)]
-        init: PackageInitArgs,
-        #[command(flatten)]
-        extract: PackageExtractArgs,
-        #[command(flatten)]
-        finish: PackageExecuteArgs,
-    },
-    /// Print the transitive dependencies of a package in topological order.
-    BuildOrder {
-        #[command(flatten)]
-        args: BuildOrderArgs,
-    },
-}
-
 #[test]
 fn verify_app() {
     use clap::CommandFactory;
@@ -113,6 +63,14 @@ fn real_main() -> Result<()> {
             }
             Ok(())
         }
+        DebDependencies { args } => {
+            let (toolchain_deps, dependencies) = deb_dependencies(args)?;
+            println!(
+                "{}",
+                toolchain_deps.into_iter().chain(dependencies).join(", ")
+            );
+            Ok(())
+        }
     }
 }
 
