@@ -30,7 +30,10 @@ pub struct Config {
     pub requires_root: Option<String>,
 
     pub source: Option<SourceOverride>,
-    pub packages: Option<HashMap<String, PackageOverride>>,
+    pub packages: HashMap<String, PackageOverride>,
+
+    #[serde(flatten)]
+    pub unknown_fields: HashMap<String, toml::Value>,
 }
 
 #[derive(Deserialize, Debug, Clone, Default)]
@@ -44,6 +47,10 @@ pub struct SourceOverride {
     build_depends_arch: Option<Vec<String>>,
     build_depends_indep: Option<Vec<String>>,
     build_depends_excludes: Option<Vec<String>>,
+    skip_nocheck: Option<bool>,
+
+    #[serde(flatten)]
+    pub unknown_fields: HashMap<String, toml::Value>,
 }
 
 impl SourceOverride {
@@ -57,6 +64,7 @@ impl SourceOverride {
         build_depends_arch: Option<Vec<String>>,
         build_depends_indep: Option<Vec<String>>,
         build_depends_excludes: Option<Vec<String>>,
+        skip_nocheck: Option<bool>,
     ) -> Self {
         Self {
             section,
@@ -68,6 +76,8 @@ impl SourceOverride {
             build_depends_arch,
             build_depends_indep,
             build_depends_excludes,
+            skip_nocheck,
+            unknown_fields: HashMap::new(),
         }
     }
 }
@@ -89,6 +99,9 @@ pub struct PackageOverride {
     test_is_broken: Option<bool>,
     test_architecture: Option<Vec<String>>,
     test_depends: Option<Vec<String>>,
+
+    #[serde(flatten)]
+    pub unknown_fields: HashMap<String, toml::Value>,
 }
 
 impl Default for Config {
@@ -108,8 +121,9 @@ impl Default for Config {
             uploaders: None,
             collapse_features: false,
             source: None,
-            packages: None,
+            packages: HashMap::new(),
             requires_root: None,
+            unknown_fields: HashMap::new(),
         }
     }
 }
@@ -120,7 +134,36 @@ impl Config {
         let mut content = String::new();
         config_file.read_to_string(&mut content)?;
 
-        Ok(toml::from_str(&content)?)
+        let config: Config = toml::from_str(&content)?;
+
+        let mut unknown_fields = Vec::new();
+
+        for field in config.unknown_fields.keys() {
+            unknown_fields.push(field.clone());
+        }
+
+        if let Some(ref source) = config.source {
+            for field in source.unknown_fields.keys() {
+                unknown_fields.push(format!("source.{}", field));
+            }
+        }
+
+        for (name, package) in &config.packages {
+            for field in package.unknown_fields.keys() {
+                unknown_fields.push(format!("packages.{}.{}", name, field));
+            }
+        }
+
+        if !unknown_fields.is_empty() {
+            debcargo_warn!(
+                "Warning: Unknown fields in {}: {:?}",
+                src.display(),
+                unknown_fields
+            );
+            debcargo_warn!("         These fields will be ignored. Please check for typos.");
+        }
+
+        Ok(config)
     }
 
     pub fn build_bin_package(&self) -> bool {
@@ -196,6 +239,10 @@ impl Config {
         self.source.as_ref()?.build_depends_excludes.as_ref()
     }
 
+    pub fn skip_nocheck(&self) -> Option<bool> {
+        self.source.as_ref()?.skip_nocheck
+    }
+
     // Packages shortcuts
 
     fn with_package<'a, T, F: FnOnce(&'a PackageOverride) -> Option<T>>(
@@ -203,10 +250,7 @@ impl Config {
         key: PackageKey,
         f: F,
     ) -> Option<T> {
-        self.packages
-            .as_ref()?
-            .get(&package_key_string(key))
-            .and_then(f)
+        self.packages.get(&package_key_string(key)).and_then(f)
     }
 
     pub fn package_section(&self, key: PackageKey) -> Option<&str> {
