@@ -29,7 +29,7 @@ pub struct Source {
     vcs_browser: String,
     homepage: String,
     crate_name: String,
-    requires_root: String,
+    requires_root: Option<String>,
 }
 
 pub struct Package {
@@ -116,7 +116,9 @@ impl fmt::Display for Source {
         //   b) "utf-8" crate at version latest with semver_suffix = false.
         // dh-cargo assumes (a) which is wrong for the "utf-8" crate
         writeln!(f, "X-Cargo-Crate: {}", self.crate_name)?;
-        writeln!(f, "Rules-Requires-Root: {}", self.requires_root)?;
+        if let Some(ref rrr) = self.requires_root {
+            writeln!(f, "Rules-Requires-Root: {}", rrr)?;
+        }
 
         Ok(())
     }
@@ -227,7 +229,7 @@ impl Source {
         maintainer: String,
         uploaders: Vec<String>,
         build_deps: BuildDeps,
-        _requires_root: String,
+        requires_root: Option<String>,
     ) -> Result<Source> {
         let pkgbase = match name_suffix {
             None => basename.to_string(),
@@ -259,7 +261,7 @@ impl Source {
             vcs_browser,
             homepage: home.to_string(),
             crate_name: crate_name.to_string(),
-            requires_root: "no".to_string(),
+            requires_root,
         })
     }
 
@@ -325,9 +327,6 @@ impl Source {
             self.vcs_browser = vcs_browser.to_string();
         }
 
-        if let Some(requires_root) = config.requires_root() {
-            self.requires_root = requires_root.to_string();
-        }
     }
 }
 
