@@ -19,11 +19,11 @@ fn source_to_string() {
         "Jelmer Vernooĳ <jelmer@debian.org>".to_owned(),
         vec!["Jelmer Vernooĳ <jelmer@debian.org>".to_owned()],
         BuildDeps::default(),
-        "no".to_owned(),
+        None,
     )
     .unwrap();
 
-    let expected = "Source: rust-rsa\nSection: rust\nPriority: optional\nMaintainer: Jelmer Vernooĳ <jelmer@debian.org>\nUploaders:\n Jelmer Vernooĳ <jelmer@debian.org>\nStandards-Version: 4.7.2\nVcs-Git: https://salsa.debian.org/rust-team/debcargo-conf.git [src/rsa]\nVcs-Browser: https://salsa.debian.org/rust-team/debcargo-conf/tree/master/src/rsa\nHomepage: https://github.com/RustCrypto/RSA\nX-Cargo-Crate: rsa\nRules-Requires-Root: no\n";
+    let expected = "Source: rust-rsa\nSection: rust\nPriority: optional\nMaintainer: Jelmer Vernooĳ <jelmer@debian.org>\nUploaders:\n Jelmer Vernooĳ <jelmer@debian.org>\nStandards-Version: 4.7.2\nVcs-Git: https://salsa.debian.org/rust-team/debcargo-conf.git [src/rsa]\nVcs-Browser: https://salsa.debian.org/rust-team/debcargo-conf/tree/master/src/rsa\nHomepage: https://github.com/RustCrypto/RSA\nX-Cargo-Crate: rsa\n";
 
     assert_eq!(expected, instance.to_string());
 }
@@ -39,6 +39,7 @@ fn empty_source_overrides() -> SourceOverride {
         Some(vec!["".to_owned()]),
         Some(vec!["".to_owned()]),
         Some(vec!["rust-const-oid".to_owned()]),
+        Some(false),
     )
 }
 
@@ -66,7 +67,7 @@ fn test_apply_overrides() {
             ],
             ..BuildDeps::default()
         },
-        "no".to_owned(),
+        Some("no".to_owned()),
     )
     .unwrap();
 
