@@ -369,23 +369,27 @@ pub fn prepare_debian_folder(
                     .uscan_version_pattern
                     .as_ref()
                     .map_or_else(|| "@ANY_VERSION@".to_string(), |ref s| s.to_string());
-                writeln!(watch, "version=4")?;
+                writeln!(watch, "Version: 5\n")?;
                 writeln!(
                     watch,
-                    r"opts=filenamemangle=s/.*\/(.*)\/download/{name}-$1\.tar\.gz/g,\",
-                    name = upstream_name
+                    "Source: https://qa.debian.org/cgi-bin/fakeupstream.cgi?upstream=crates.io/{name}",
+                    name = upstream_name,
                 )?;
                 writeln!(
                     watch,
-                    r"uversionmangle=s/(\d)[_\.\-\+]?((RC|rc|pre|dev|beta|alpha)\.?\d*)$/$1~$2/ \"
-                )?;
-                writeln!(
-                    watch,
-                    "https://qa.debian.org/cgi-bin/fakeupstream.cgi?upstream=crates.io/{name} \
-                     .*/crates/{name}/{version_pattern}/download",
+                    "Matching-Pattern:  .*/crates/{name}/{version_pattern}/download",
                     name = upstream_name,
                     version_pattern = uscan_version_pattern
                 )?;
+                writeln!(
+                    watch,
+                    r"Filenamemangle: s/.*\/(.*)\/download/{name}-$1\.tar\.gz/g",
+                    name = upstream_name,
+                )?;
+                writeln!(
+                    watch,
+                    r"Uversionmangle: s/(\d)[_\.\-\+]?((RC|rc|pre|dev|beta|alpha)\.?\d*)$/$1~$2/"
+                )?;
             }
         };
     }
@@ -706,7 +710,13 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
             assert!(lib);
             build_deps
                 .build_depends_arch
-                .extend(build_deps_arch.map(|d| deb_dep_add_nocheck(&d)));
+                .extend(build_deps_arch.map(|d| {
+                    if config.skip_nocheck().unwrap_or(false) {
+                        d
+                    } else {
+                        deb_dep_add_nocheck(&d)
+                    }
+                }));
         }
         build_deps
     };
@@ -731,11 +741,7 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
         maintainer.to_string(),
         uploaders.iter().map(|s| s.to_string()).collect(),
         build_deps,
-        if requires_root.is_some() {
-            requires_root.as_ref().unwrap().to_string()
-        } else {
-            "no".to_string()
-        },
+        requires_root.cloned(),
     )?;
 
     // If source overrides are present update related parts.
@@ -895,6 +901,11 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
             }
         }
 
+        let mut no_features_edge_case = BTreeMap::new();
+        no_features_edge_case.insert("", (vec![], vec![]));
+        no_features_edge_case.insert("default", (vec![""], vec![]));
+        let no_features_edge_case = features_with_deps == no_features_edge_case;
+
         for (feature, (f_deps, o_deps)) in reduced_features_with_deps.into_iter() {
             let pk = PackageKey::feature(feature);
             let f_provides = provides.remove(feature).unwrap();
@@ -994,44 +1005,47 @@ fn prepare_debian_control<F: FnMut(&str) -> std::result::Result<fs::File, io::Er
             }
 
             // Generate tests for all features in this package
-            for f in crate_features {
-                let (feature_deps, _) = transitive_deps(&features_with_deps, f)?;
+            if !no_features_edge_case {
+                for f in crate_features {
+                    let (feature_deps, _) = transitive_deps(&features_with_deps, f)?;
 
-                // args
-                let mut args = if f == "default" || feature_deps.contains(&"default") {
-                    vec![]
-                } else {
-                    vec!["--no-default-features"]
-                };
-                // --features default sometimes fails, see
-                // https://github.com/rust-lang/cargo/issues/8164
-                if !f.is_empty() && f != "default" {
-                    args.push("--features");
-                    args.push(f);
-                }
-
-                // deps
-                let test_depends = generate_test_dependencies(f, &feature_deps, config, &test_deps);
-                let test_arch = match test_architecture(f)? {
-                    Some(v) => v.to_owned(),
-                    None => Vec::new(),
-                };
-                let test_arch: Vec<&str> = test_arch.iter().map(AsRef::as_ref).collect();
-                let pkgtest = PkgTest::new(
-                    package.name(),
-                    crate_name,
-                    f,
-                    deb_upstream_version,
-                    args,
-                    &test_depends,
-                    if test_is_broken(f)? {
-                        vec!["flaky"]
-                    } else {
+                    // args
+                    let mut args = if f == "default" || feature_deps.contains(&"default") {
                         vec![]
-                    },
-                    test_arch.deref(),
-                )?;
-                write!(testctl, "\n{}", pkgtest)?;
+                    } else {
+                        vec!["--no-default-features"]
+                    };
+                    // --features default sometimes fails, see
+                    // https://github.com/rust-lang/cargo/issues/8164
+                    if !f.is_empty() && f != "default" {
+                        args.push("--features");
+                        args.push(f);
+                    }
+
+                    // deps
+                    let test_depends =
+                        generate_test_dependencies(f, &feature_deps, config, &test_deps);
+                    let test_arch = match test_architecture(f)? {
+                        Some(v) => v.to_owned(),
+                        None => Vec::new(),
+                    };
+                    let test_arch: Vec<&str> = test_arch.iter().map(AsRef::as_ref).collect();
+                    let pkgtest = PkgTest::new(
+                        package.name(),
+                        crate_name,
+                        f,
+                        deb_upstream_version,
+                        args,
+                        &test_depends,
+                        if test_is_broken(f)? {
+                            vec!["flaky"]
+                        } else {
+                            vec![]
+                        },
+                        test_arch.deref(),
+                    )?;
+                    write!(testctl, "\n{}", pkgtest)?;
+                }
             }
         }
         assert!(provides.is_empty());
