@@ -1,9 +1,11 @@
 #[macro_use]
 pub mod errors;
+pub mod cli;
 pub mod config;
 pub mod crates;
 pub mod debian;
 mod util;
 
 pub mod build_order;
+pub mod deb_dependencies;
 pub mod package;
