@@ -49,7 +49,8 @@ pub fn hint_file_for(file: &Path) -> Option<Cow<'_, Path>> {
 
 pub fn lookup_fixmes(srcdir: &Path) -> Result<BTreeSet<PathBuf>, Error> {
     let mut fixmes = BTreeSet::new();
-    for entry in WalkDir::new(srcdir) {
+    let debiandir = srcdir.join("debian");
+    for entry in WalkDir::new(debiandir) {
         let entry = entry?;
         if entry.file_type().is_file() {
             let file = fs::File::open(entry.path())?;
@@ -57,9 +58,21 @@ pub fn lookup_fixmes(srcdir: &Path) -> Result<BTreeSet<PathBuf>, Error> {
             // If we find one FIXME we break the loop and check next file. Idea
             // is only to find files with FIXME strings in it.
             for line in reader.lines() {
-                if line?.contains("FIXME") {
-                    fixmes.insert(entry.path().to_path_buf());
-                    break;
+                match line {
+                    Ok(line_content) => {
+                        if line_content.contains("FIXME") {
+                            fixmes.insert(entry.path().to_path_buf());
+                            break;
+                        }
+                    }
+                    Err(e) => {
+                        debcargo_warn!(
+                            "Warning: Could not check for FIXMEs in file {:?}: {}",
+                            rel_p(entry.path(), srcdir),
+                            e
+                        );
+                        break;
+                    }
                 }
             }
         }
@@ -77,8 +90,8 @@ pub fn lookup_fixmes(srcdir: &Path) -> Result<BTreeSet<PathBuf>, Error> {
     Ok(fixmes)
 }
 
-pub fn rel_p<'a>(path: &'a Path, base: &'a Path) -> &'a str {
-    path.strip_prefix(base).unwrap_or(path).to_str().unwrap()
+pub fn rel_p<'a>(path: &'a Path, base: &'a Path) -> Cow<'a, str> {
+    path.strip_prefix(base).unwrap_or(path).to_string_lossy()
 }
 
 pub fn copy_tree(oldtree: &Path, newtree: &Path) -> Result<(), Error> {
